@@ -1,7 +1,6 @@
 //! Contains the blocking [Client] trait for executing
 //! [Endpoints][crate::endpoint::Endpoint].
 use crate::{client::HTTP_SUCCESS_CODES, errors::ClientError};
-use bytes::Bytes;
 use http::{Request, Response};
 
 /// Represents an HTTP client which is capable of executing
@@ -10,7 +9,7 @@ use http::{Request, Response};
 pub trait Client {
     /// Sends the given [Request] and returns a [Response]. Implementations
     /// should consolidate all errors into the [ClientError] type.
-    fn send(&self, req: Request<Bytes>) -> Result<Response<Bytes>, ClientError>;
+    fn send(&self, req: Request<Vec<u8>>) -> Result<Response<Vec<u8>>, ClientError>;
 
     /// Returns the base URL the client is configured with. This is used for
     /// creating the fully qualified URLs used when executing
@@ -19,8 +18,9 @@ pub trait Client {
 
     /// This method provides a common interface to
     /// [Endpoints][crate::endpoint::Endpoint] for execution.
-    fn execute(&self, req: Request<Bytes>) -> Result<Response<Bytes>, ClientError> {
-        log::info!(
+    #[instrument(skip(self, req), err)]
+    fn execute(&self, req: Request<Vec<u8>>) -> Result<Response<Vec<u8>>, ClientError> {
+        debug!(
             "Client sending {} request to {} with {} bytes of data",
             req.method().to_string(),
             req.uri(),
@@ -28,7 +28,7 @@ pub trait Client {
         );
         let response = self.send(req)?;
 
-        log::info!(
+        debug!(
             "Client received {} response with {} bytes of body data",
             response.status().as_u16(),
             response.body().len()
